@@ -15,6 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -28,12 +32,12 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <ktextedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcombobox.h>
 #include <kpushbutton.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kstdguiitem.h>
 #include <kiconloader.h>
 #include <kguiitem.h>
@@ -55,7 +59,7 @@
 
 #include "../dialogs/ksplittransactiondlg.h"
 #include "../dialogs/kcurrencycalculator.h"
-#include "../dialogs/kselecttransactionsdlg.h"
+#include "../dialogs/tdeselecttransactionsdlg.h"
 
 using namespace KMyMoneyRegister;
 using namespace KMyMoneyTransactionForm;
@@ -281,7 +285,7 @@ int TransactionEditor::slotEditSplits(void)
           *m_transactionPtr = k;
         }
       } catch(MyMoneyException *e) {
-        qDebug("Unable to update commodity to second splits currency in %s: '%s'", m_transaction.id().data(), e->what().data());
+        tqDebug(TQString("Unable to update commodity to second splits currency in %1: '%2'").arg(m_transaction.id()).arg(e->what()));
         delete e;
       }
 
@@ -357,7 +361,7 @@ bool TransactionEditor::fixTransactionCommodity(const MyMoneyAccount& account)
             (*it_t).transaction().modifySplit(splitB);
 
           } catch(MyMoneyException *e) {
-            qDebug("Unable to update commodity to second splits currency in %s: '%s'", (*it_t).transaction().id().data(), e->what().data());
+            tqDebug(TQString("Unable to update commodity to second splits currency in %1: '%2'").arg((*it_t).transaction().id()).arg(e->what()));
             delete e;
           }
           break;
@@ -394,7 +398,7 @@ bool TransactionEditor::fixTransactionCommodity(const MyMoneyAccount& account)
             (*it_t).transaction().modifySplit(splitB);
 
           } catch(MyMoneyException *e) {
-            qDebug("Unable to update commodity to second splits currency in %s: '%s'", (*it_t).transaction().id().data(), e->what().data());
+            tqDebug(TQString("Unable to update commodity to second splits currency in %1: '%2'").arg((*it_t).transaction().id()).arg(e->what()));
             delete e;
           }
           break;
@@ -440,7 +444,7 @@ bool TransactionEditor::fixTransactionCommodity(const MyMoneyAccount& account)
               }
             }
           } catch(MyMoneyException *e) {
-            qDebug("Unable to update commodity of split currency in %s: '%s'", (*it_t).transaction().id().data(), e->what().data());
+            tqDebug(TQString("Unable to update commodity of split currency in %1: '%2'").arg((*it_t).transaction().id()).arg(e->what()));
             delete e;
           }
           break;
@@ -601,13 +605,13 @@ bool TransactionEditor::enterTransactions(TQString& newId, bool askForSchedule,
           bool enter = true;
           if(askForSchedule && (*it_ts).postDate() > TQDate::currentDate()) {
             KGuiItem enterItem;
-            KIconLoader* il = KGlobal::iconLoader();
+            TDEIconLoader* il = TDEGlobal::iconLoader();
             KGuiItem enterButton( i18n("&Enter" ),
-                    TQIconSet(il->loadIcon("kontact_journal", KIcon::Small, KIcon::SizeSmall)),
+                    TQIconSet(il->loadIcon("kontact_journal", TDEIcon::Small, TDEIcon::SizeSmall)),
                     i18n("Accepts the entered data and stores it"),
                     i18n("Use this to enter the transaction into the ledger."));
             KGuiItem scheduleButton( i18n("&Schedule" ),
-                    TQIconSet(il->loadIcon("kontact_date", KIcon::Small, KIcon::SizeSmall)),
+                    TQIconSet(il->loadIcon("kontact_date", TDEIcon::Small, TDEIcon::SizeSmall)),
                     i18n("Accepts the entered data and stores it as schedule"),
                     i18n("Use this to schedule the transaction for later entry into the ledger."));
 
@@ -707,7 +711,7 @@ bool TransactionEditor::enterTransactions(TQString& newId, bool askForSchedule,
         }
       }
     } catch(MyMoneyException * e) {
-      qDebug("Unable to store transaction within engine: %s", e->what().latin1());
+      tqDebug(TQString("Unable to store transaction within engine: %1").arg(e->what()));
       delete e;
       newTransactionCreated = false;
     }
@@ -748,7 +752,7 @@ bool StdTransactionEditor::eventFilter(TQObject* o, TQEvent* e)
   if((e->type() == TQEvent::FocusOut)
   && (haveWidget("payee") == dynamic_cast<TQWidget*>(o))) {
     // loosing the focus on the payee widget?
-    qDebug("Loosing focus on payee");
+    tqDebug("Loosing focus on payee");
     KMyMoneyPayeeCombo* p = dynamic_cast<KMyMoneyPayeeCombo*>(haveWidget("payee"));
     if(!p->selectedItem().isEmpty())
       slotUpdatePayee(p->selectedItem());
@@ -1286,7 +1290,7 @@ void StdTransactionEditor::autoFill(const TQString& payeeId)
         t = list.last().first;
       } else {
 #endif
-        KSelectTransactionsDlg dlg(m_account, m_regForm);
+        TDESelectTransactionsDlg dlg(m_account, m_regForm);
         dlg.setCaption(i18n("Select autofill transaction"));
 
         TQMap<TQString, struct uniqTransaction>::const_iterator it_u;
@@ -1421,7 +1425,7 @@ void StdTransactionEditor::slotUpdateCashFlow(KMyMoneyRegister::CashFlowDirectio
 {
   TQLabel* categoryLabel = dynamic_cast<TQLabel*>(haveWidget("category-label"));
 
-  // qDebug("Update cashflow to %d", dir);
+  // tqDebug("Update cashflow to %d", dir);
   if(categoryLabel) {
     TabBar* tabbar = dynamic_cast<TabBar*>(haveWidget("tabbar"));
     if(categoryLabel->text() != i18n("Category")) {
@@ -1443,7 +1447,7 @@ void StdTransactionEditor::slotUpdateCashFlow(KMyMoneyRegister::CashFlowDirectio
 void StdTransactionEditor::slotUpdateCategory(const TQString& id)
 {
   TQLabel *categoryLabel = dynamic_cast<TQLabel*>(haveWidget("category-label"));
-  // qDebug("Update category to %s", id.data());
+  // tqDebug(TQString("Update category to %1").arg(id));
 
   if(categoryLabel) {
     TabBar* tabbar = dynamic_cast<TabBar*>(haveWidget("tabbar"));
@@ -1522,7 +1526,7 @@ void StdTransactionEditor::slotUpdateDeposit(const TQString& txt)
 
 void StdTransactionEditor::slotUpdateAmount(const TQString& txt)
 {
-  // qDebug("Update amount to %s", txt.data());
+  // tqDebug(TQString("Update amount to %1").arg(txt));
   MyMoneyMoney val(txt);
   updateAmount(val);
   updateVAT(true);
@@ -1645,7 +1649,7 @@ bool StdTransactionEditor::addVatSplit(MyMoneyTransaction& tr, const MyMoneyMone
     const MyMoneySecurity& csec = file->security(category.currencyId());
     const MyMoneySecurity& vsec = file->security(vatAcc.currencyId());
     if(asec.id() != csec.id() || asec.id() != vsec.id()) {
-      qDebug("Auto VAT assignment only works if all three accounts use the same currency.");
+      tqDebug("Auto VAT assignment only works if all three accounts use the same currency.");
       return false;
     }
 
@@ -1657,7 +1661,7 @@ bool StdTransactionEditor::addVatSplit(MyMoneyTransaction& tr, const MyMoneyMone
 
       tax.setAccountId(vatAcc.id());
 
-      // qDebug("vat amount is '%s'", category.value("VatAmount").latin1());
+      // tqDebug(TQString("vat amount is '%1'").arg(category.value("VatAmount")));
       if(category.value("VatAmount").lower() != TQString("net")) {
         // split value is the gross value
         gv = amount;
@@ -1857,7 +1861,7 @@ int StdTransactionEditor::slotEditSplits(void)
         }
       }
       if(!deposit || !payment) {
-        qDebug("Internal error: deposit(%p) & payment(%p) widgets not found but required", deposit, payment);
+        tqDebug("Internal error: deposit(%p) & payment(%p) widgets not found but required", deposit, payment);
         return rc;
       }
     }
