@@ -18,10 +18,6 @@
 #ifndef MYMONEYBUDGET_H
 #define MYMONEYBUDGET_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // ----------------------------------------------------------------------------
 // QT Includes
 
