@@ -18,10 +18,6 @@
 #ifndef KOFXDIRECTCONNECTDLG_H
 #define KOFXDIRECTCONNECTDLG_H
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 // ----------------------------------------------------------------------------
 // QT Includes
 
