@@ -360,7 +360,7 @@ void OfxHttpsRequest::slotOfxFinished(TDEIO::Job* /* e */)
   int error = m_job->error();
   if ( error ) {
     m_job->showErrorDialog();
-    unlink(m_dst.path());
+    unlink(m_dst.path().local8Bit());
 
   } else if ( m_job->isErrorPage() ) {
     TQString details;
@@ -374,7 +374,7 @@ void OfxHttpsRequest::slotOfxFinished(TDEIO::Job* /* e */)
       f.close();
     }
     KMessageBox::detailedSorry( 0, i18n("The HTTP request failed."), details, i18n("Failed") );
-    unlink(m_dst.path());
+    unlink(m_dst.path().local8Bit());
   }
 
   tqApp->exit_loop();
@@ -414,7 +414,7 @@ OfxHttpRequest::OfxHttpRequest(const TQString& type, const KURL &url, const TQBy
 
   if(m_error != TQHttp::NoError) {
     KMessageBox::error(0, errorMsg, i18n("OFX setup error"));
-    unlink(dst.path());
+    unlink(dst.path().local8Bit());
   }
 }
 
@@ -427,5 +427,3 @@ void OfxHttpRequest::slotOfxFinished(int, bool rc)
 }
 
 #include "ofxpartner.moc"
-
-// vim:cin:si:ai:et:ts=2:sw=2:
